@@ -38,17 +38,16 @@
  ** GxRegler
  */
 
-#define GX_REGLER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GX_TYPE_REGLER, GxReglerPrivate))
-
-typedef struct
+struct _GxReglerPrivate
 {
 	GtkRequisition value_req;
 	gdouble last_step;
 	GtkAdjustment *adjustment;
-} GxReglerPrivate;
+};
 
 enum {
   VALUE_ENTRY,
+  VALUES_ENTRY,
   FORMAT_VALUE,
   LAST_SIGNAL
 };
@@ -155,7 +154,7 @@ static gboolean single_string_accumulator(
 
 /*
 ** marshalers generated with
-** echo -e 'STRING:DOUBLE\nBOOLEAN:BOXED,BOXED' | \
+** echo -e 'STRING:DOUBLE\nBOOLEAN:BOXED' | \
 **   glib-genmarshal --prefix='marshal' --skip-source --nostdinc --body
 **
 ** manually added static to funktion definitions
@@ -163,6 +162,8 @@ static gboolean single_string_accumulator(
 ** definitions are used at other places
 */
 // begin generated marshalers
+
+
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
 #define g_marshal_value_peek_char(v)     g_value_get_char (v)
@@ -182,6 +183,7 @@ static gboolean single_string_accumulator(
 #define g_marshal_value_peek_boxed(v)    g_value_get_boxed (v)
 #define g_marshal_value_peek_pointer(v)  g_value_get_pointer (v)
 #define g_marshal_value_peek_object(v)   g_value_get_object (v)
+#define g_marshal_value_peek_variant(v)  g_value_get_variant (v)
 #else /* !G_ENABLE_DEBUG */
 /* WARNING: This code accesses GValues directly, which is UNSUPPORTED API.
  *          Do not access GValues directly in your code. Instead, use the
@@ -205,6 +207,7 @@ static gboolean single_string_accumulator(
 #define g_marshal_value_peek_boxed(v)    (v)->data[0].v_pointer
 #define g_marshal_value_peek_pointer(v)  (v)->data[0].v_pointer
 #define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
+#define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
 
@@ -247,19 +250,20 @@ marshal_STRING__DOUBLE (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
+
 /* BOOLEAN:BOXED,BOXED */
 void
 marshal_BOOLEAN__BOXED_BOXED (GClosure     *closure,
-                              GValue       *return_value G_GNUC_UNUSED,
-                              guint         n_param_values,
-                              const GValue *param_values,
-                              gpointer      invocation_hint G_GNUC_UNUSED,
-                              gpointer      marshal_data)
+                        GValue       *return_value G_GNUC_UNUSED,
+                        guint         n_param_values,
+                        const GValue *param_values,
+                        gpointer      invocation_hint G_GNUC_UNUSED,
+                        gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__BOXED_BOXED) (gpointer     data1,
-                                                         gpointer     arg_1,
-                                                         gpointer     arg_2,
-                                                         gpointer     data2);
+                                                   gpointer     arg_1,
+                                                   gpointer     arg_2,
+                                                   gpointer     data2);
   register GMarshalFunc_BOOLEAN__BOXED_BOXED callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
@@ -287,6 +291,7 @@ marshal_BOOLEAN__BOXED_BOXED (GClosure     *closure,
 
   g_value_set_boolean (return_value, v_return);
 }
+
 // end generated marshalers
 
 
@@ -320,7 +325,7 @@ static void gx_regler_class_init(GxReglerClass *klass)
 	range_class->move_slider = gx_regler_move_slider;
 
 	klass->value_entry = gx_regler_value_entry;
-
+	
 	signals[VALUE_ENTRY] =
 		g_signal_new (I_("value-entry"),
 		              G_OBJECT_CLASS_TYPE (klass),
@@ -330,15 +335,16 @@ static void gx_regler_class_init(GxReglerClass *klass)
 		              marshal_BOOLEAN__BOXED_BOXED,
 		              G_TYPE_BOOLEAN, 2, GDK_TYPE_RECTANGLE,
 		              GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
-  signals[FORMAT_VALUE] =
-    g_signal_new (I_("format-value"),
-                  G_TYPE_FROM_CLASS (gobject_class),
-                  G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (GxReglerClass, format_value),
-                  single_string_accumulator, NULL,
-                  marshal_STRING__DOUBLE,
-                  G_TYPE_STRING, 1,
-                  G_TYPE_DOUBLE);
+
+	signals[FORMAT_VALUE] =
+		g_signal_new (I_("format-value"),
+					  G_TYPE_FROM_CLASS (gobject_class),
+					  G_SIGNAL_RUN_LAST,
+					  G_STRUCT_OFFSET (GxReglerClass, format_value),
+					  single_string_accumulator, NULL,
+					  marshal_STRING__DOUBLE,
+					  G_TYPE_STRING, 1,
+					  G_TYPE_DOUBLE);
 
 	gtk_widget_class_install_style_property(
 		widget_class,
@@ -508,6 +514,7 @@ static void gx_regler_class_init(GxReglerClass *klass)
 	g_type_class_add_private(klass, sizeof (GxReglerPrivate));
 }
 
+
 static void gx_regler_destroy(GtkObject *object)
 {
 	GxRegler *regler = GX_REGLER(object);
@@ -701,7 +708,7 @@ static void gx_regler_move_slider(GtkRange *range, GtkScrollType scroll)
 
 static void ensure_digits(GxRegler *regler)
 {
-	GxReglerPrivate *priv = GX_REGLER_GET_PRIVATE(regler);
+	GxReglerPrivate *priv = regler->priv;
 	GtkAdjustment *adj = GTK_RANGE(regler)->adjustment;
 	if (!adj) {
 		return;
@@ -748,7 +755,7 @@ gboolean _approx_in_rectangle(gdouble x, gdouble y, GdkRectangle *rect)
 	if (rect->width == 0 || rect->height == 0) {
 		return FALSE;
 	}
-	if (x >= rect->x-off && x < rect->x + rect->width + off &&
+	else if (x >= rect->x-off && x < rect->x + rect->width + off &&
 	    y >= rect->y-off && y < rect->y + rect->height + off) {
 		return TRUE;
 	}
@@ -791,7 +798,7 @@ void _gx_regler_get_positions(GxRegler *regler, GdkRectangle *image_rect,
 	gint width = image_rect->width;
 	gint height =  image_rect->height;
 	if (regler->show_value) {
-		GxReglerPrivate *priv = GX_REGLER_GET_PRIVATE(regler);
+		GxReglerPrivate *priv = regler->priv;
 		gint text_width = priv->value_req.width;
 		gint text_height = priv->value_req.height;
 		gint text_x = 0, text_y = 0;
@@ -962,7 +969,7 @@ void _gx_regler_calc_size_request(GxRegler *regler, GtkRequisition *requisition)
 		pango_layout_get_pixel_extents(regler->value_layout, NULL, &logical_rect2);
 		gint height = max(logical_rect1.height,logical_rect2.height) + border.top + border.bottom;
 		gint width = max(logical_rect1.width,logical_rect2.width) + border.left + border.right;
-		GxReglerPrivate *priv = GX_REGLER_GET_PRIVATE(regler);
+		GxReglerPrivate *priv = regler->priv;
 		priv->value_req.width = width;
 		priv->value_req.height = height;
 		switch (regler->value_position) {
@@ -1034,7 +1041,8 @@ static gboolean dialog_key_press_event(
 	if (event->is_modifier) {
 		return FALSE;
 	}
-	gtk_widget_destroy(GTK_WIDGET(data));
+	if (GTK_IS_WIDGET(data));
+		gtk_widget_destroy(GTK_WIDGET(data));
 	return FALSE;
 }
 
@@ -1044,7 +1052,8 @@ static gboolean dialog_key_press_before(
 	if (event->keyval == GDK_Escape) {
 		// spinbutton to current adjustment value
 		gtk_adjustment_value_changed(GTK_SPIN_BUTTON(widget)->adjustment);
-		gtk_widget_destroy(GTK_WIDGET(data));
+		if (GTK_IS_WIDGET(data));
+			gtk_widget_destroy(GTK_WIDGET(data));
 		return TRUE;
 	}
 	return FALSE;
@@ -1053,7 +1062,8 @@ static gboolean dialog_key_press_before(
 static gboolean dialog_grab_broken(
 	GtkWidget *widget, GdkEvent *event, gpointer data)
 {
-	gtk_widget_destroy(GTK_WIDGET(data));
+	if (GTK_IS_WIDGET(data));
+		gtk_widget_destroy(GTK_WIDGET(data));
 	return FALSE;
 }
 
@@ -1095,6 +1105,7 @@ static gboolean gx_regler_value_entry(GxRegler *regler, GdkRectangle *rect, GdkE
 		GTK_ADJUSTMENT(adj), adj->step_increment,
 		GTK_RANGE(regler)->round_digits);
 	gtk_container_add (GTK_CONTAINER(dialog), spinner);
+	
 	g_signal_connect(spinner, "button-press-event", G_CALLBACK(spinner_button_press_event), NULL);
 	g_signal_connect(dialog, "button-press-event", G_CALLBACK(dialog_button_press_event), dialog);
 	g_signal_connect(spinner, "key-press-event", G_CALLBACK(dialog_key_press_before), dialog);
@@ -1102,14 +1113,16 @@ static gboolean gx_regler_value_entry(GxRegler *regler, GdkRectangle *rect, GdkE
 	g_signal_connect_object(spinner, "activate", G_CALLBACK(gtk_widget_destroy), dialog, (GConnectFlags)(G_CONNECT_AFTER|G_CONNECT_SWAPPED));
 	g_signal_connect(dialog, "grab-broken-event", G_CALLBACK(dialog_grab_broken), dialog);
 	g_signal_connect(dialog, "map-event", G_CALLBACK(map_check), GTK_WIDGET(regler));
+	
 	gtk_window_move(GTK_WINDOW(dialog), -100, -100); // trick so its not visible
 	gtk_widget_show_all(dialog);
 	GtkRequisition rq;
 	gtk_widget_get_requisition(dialog, &rq);
 	gint xorg, yorg;
 	gdk_window_get_origin(GTK_WIDGET(regler)->window, &xorg, &yorg);
+	
 	gtk_window_move(GTK_WINDOW(dialog), xorg+rect->x+(rect->width-rq.width)/2, yorg+rect->y+(rect->height-rq.height)/2);
-	return TRUE;
+	return FALSE;
 }
 
 /****************************************************************
@@ -1130,9 +1143,12 @@ static gboolean gx_regler_button_release (GtkWidget *widget, GdkEventButton *eve
 
 static gboolean gx_regler_scroll (GtkWidget *widget, GdkEventScroll *event)
 {
+	
 	usleep(5000);
+	
 	gx_regler_set_value(widget, event->direction);
-	return FALSE;
+	
+	return TRUE;
 }
 
 
@@ -1152,7 +1168,7 @@ static void gx_regler_adjustment_changed(GtkAdjustment *adjustment, gpointer dat
 
 static void gx_regler_change_adjustment(GxRegler *regler, GtkAdjustment *adjustment)
 {
-	GxReglerPrivate *priv = GX_REGLER_GET_PRIVATE(regler);
+	GxReglerPrivate *priv = regler->priv;
 	if (adjustment == priv->adjustment) {
 		return;
 	}
@@ -1179,6 +1195,7 @@ static void gx_regler_adjustment_notified(GObject *gobject, GParamSpec *pspec)
 
 static void gx_regler_init(GxRegler *regler)
 {
+	regler->priv = G_TYPE_INSTANCE_GET_PRIVATE (regler, GX_TYPE_REGLER, GxReglerPrivate);
 	GTK_RANGE(regler)->round_digits = 0;
 	regler->value_position = GTK_POS_BOTTOM;
 	regler->show_value = TRUE;
