@@ -36,22 +36,73 @@ class AudioVariables
 {
 public:
 	GxMidiState midistate;
+
 	bool fnoise_g;
 	bool fng;
-	float fnglevel;
-	bool fcheckbox1;
-	bool fupsample;
-	bool antialis0;
-	bool ftube;
-	bool ftube3;
-	bool fprdr;
-	bool fconvolve;
-	float convolvefilter;
-	bool fresoon;
-	float posit0;
+	bool foverdrive4;
+	bool fcheckbox4;
 	bool fcheckbox5;
-	float fautowah;
+	bool fcheckbox6;
+	bool fcheckbox8;
+	bool ftube;
+	bool fboost;
 	bool fcheckboxcom1;
+	bool midistat1;
+	bool midistat2;
+	bool midistat3;
+	bool feq;
+	bool fmoog;
+	bool fflanger;
+	bool fbiquad;
+	bool fcab;
+	bool fcon;
+	bool flh;
+	bool fmi;
+	bool fwv;
+	bool fwv_on;
+	bool famp;
+	bool fampout;
+	bool ftone;
+	bool ftremolo;
+	bool fpm;
+	bool fflanger_mono;
+	bool ffeedback;
+	bool ftonestack;
+	
+
+	int fcheckbox7;
+	int fdelay;
+	int fchorus;
+	int fchorus_mono;
+	int fphaser;
+	int tonestack;
+	int cabinet;
+	int cab_switched;
+	int crybabypp;
+	int overdrivepp;
+	int distortionpp;
+	int freeverbpp;
+	int IRpp;
+	int compressorpp;
+	int echopp;
+	int delaypp;
+	int eqpp;
+	int lhpp;
+	int wvpp;
+	int bipp;
+	int trpp;
+	int pmpp;
+	int chpp;
+	int flpp;
+	int ffb;
+	int fsd;
+	int fse;
+	int fts;
+	int fcb;
+	int gxtube;
+	int mono_plug_counter;
+	int stereo_plug_counter;
+
 	float posit1;
 	float posit2;
 	float posit3;
@@ -61,66 +112,42 @@ public:
 	float posit7;
 	float posit8;
 	float posit9;
-	bool foverdrive4;
-	bool fcheckbox4;
-	bool fcheckbox6;
-	int fcheckbox7;
-	bool fcheckbox8;
-	int fdelay;
-	bool fmultifilter;
-	bool fboost;
-	int fchorus;
+	float posit10;
+	float posit11;
+	float posit12;
+	float posit14;
+	float posit15;
+	float posit16;
+	float posit17;
+	float posit18;
+	float posit19;
+	float posit20;
+	float posit21;
+	float posit22;
+	float posit23;
+	float posit24;
+	float posit25;
+	float posit26;
+	float posit27;
+	float posit00;
+	float fnglevel;
+	float posit0;
+	float fautowah;
 	float ffuse;
-	bool fdialogbox1;
-	bool fdialogbox2;
-	bool fdialogbox3;
-	bool fdialogbox4;
-//float fdialogbox5;
-	bool fdialogbox6;
-	bool fdialogbox8;
-	bool fdialogboxj;
-	float fexpand;
-	float fexpand2;
 	float fwarn;
 	float fwarn_swap;
 	float fskin;
 	float viv;
 	float vivi;
-	bool fchorusbox;
 	float filebutton;
 	float fConsta1t;
 	float midistat;
-	bool feq;
-	bool fdialogbox_eq;
-	bool fdialogbox_eqs;
-	bool fdialogbox_mbf;
-	bool fdialogbox_moo;
-	bool fmoog;
-	bool fflanger;
-	bool fflangerbox;
-	bool fbiquad;
-	bool fbiquadbox;
-	bool ftube3e;
-	float upsample_mode;
 	float fampexpand;
-	int fsloop;
-	float witchdistortion;
-	bool fdis1;
-	bool fcab;
-	bool fdialogbox_echo;
-	bool fdialogbox_delay;
-	float witcheq;
-	float witchamp;
-	bool famp2;
-	int tonestack;
-	int crybabypp;
-	int overdrivepp;
-	int distortionpp;
-	int freeverbpp;
-	int IRpp;
-	int compressorpp;
-	int echopp;
-	int delaypp;
+	float cab_level;
+	float cab_bass;
+	float cab_treble;
+	float cab_sum;
+	
 
 	void register_parameter();
 };
@@ -157,36 +184,39 @@ public:
 	float beat0;
 	float midi_gain;
 	float fConstun0;
-	int   weg;
-	int   program;
-	unsigned char* midi_send;
-	int   send;
 	float fautogain;
-	int   volume;
 	float fpitch;
-	int   noten;
 	float fslider32;
-	bool fcheckbox10;
-	int   program1;
-	int   send1;
-	int   noten1;
 	float fautogain1;
-	int   volume1;
-	unsigned char* midi_send1;
-	int   send2;
-	int   noten2;
 	float fpitch1;
 	float fpitch2;
-	bool fcheckbox11;
-	int   program2;
-	int   volume2;
-	int Beat_is;
-	unsigned char* midi_send2;
 	float fautogain2;
 	float BeatFilter1;
 	float BeatFilter2;
 	float BeatFilterk;
 
+	int   weg;
+	int   program;
+	int   program2;
+	int   volume2;
+	int   Beat_is;
+	int   send;
+	int   volume;
+	int   noten;
+	int   program1;
+	int   send1;
+	int   noten1;
+	int   volume1;
+	int   send2;
+	int   noten2;
+
+	bool fcheckbox10;
+	bool fcheckbox11;
+
+	unsigned char* midi_send;
+	unsigned char* midi_send1;
+	unsigned char* midi_send2;
+
 	void register_parameter();
 	void init(int samplingFreq);
 };
@@ -206,6 +236,12 @@ inline bool isMidiOn() { return (audio.midistate == kMidiOn ? true : false); }
 inline void turnOffMidi() { audio.midistate = kMidiOff; }
 inline void turnOnMidi() { audio.midistate = kMidiOn; }
 
+inline void set_tube_model(int x) {audio.gxtube = x;}
+inline void set_cab_mode(float x) {audio.cab_sum = x;}
+inline void set_mono_plug_counter(int x) {audio.mono_plug_counter = x;}
+inline void set_stereo_plug_counter(int x) {audio.stereo_plug_counter = x;}
+
+
 /* function declarations  */
 void register_faust_parameters();
 void gx_engine_init( const string *optvar );
@@ -222,6 +258,9 @@ void moving_filter(float* input, float* output, int sf);
 void process_buffers(int count, float* input, float* output0);
 void process_insert_buffers (int count, float* input1, float* output0, float* output1);
 
+void init_non_rt_processing();
+void non_rt_processing(int count, float* input, float* output0);
+
 #ifdef EXPERIMENTAL
 void faust_setup();
 void toggle_exp_window(bool v);
