@@ -129,16 +129,6 @@ enum {
 
 /* -------------------------------------------------------------------------- */
 
-/* ----- JConv namespace ----- */
-namespace gx_jconv
-{
-/* some global vars */
-extern float checkbox7;
-extern GtkWidget* mslider;
-}
-
-/* -------------------------------------------------------------------------- */
-
 /* ----- preset namespace ----- */
 namespace gx_preset
 {
@@ -149,6 +139,7 @@ extern const char* preset_menu_name[];
 //extern map<GtkMenuItem*, string> preset_list[];
 
 extern string gx_current_preset;
+extern string gx_factory_preset;
 extern string old_preset_name;
 
 extern GtkWidget* presmenu[];
@@ -157,6 +148,13 @@ extern GtkWidget* presMenu[];
 extern vector<string> plist;
 extern vector<GtkMenuItem*> pm_list[];
 extern bool setting_is_preset;
+extern bool setting_is_factory;
+
+extern GtkWidget* fpresmenu;
+extern GtkWidget* ffpresmenu[];
+
+extern vector<string> fplist[];
+extern vector<GtkMenuItem*> fpm_list[];
 
 extern GCallback preset_action_func[];
 }
@@ -195,25 +193,20 @@ extern const char* shell_var_name[];
 /* ----- GUI namespace ----- */
 namespace gx_gui
 {
-typedef enum {
-	kWvMode1 = 1,
-	kWvMode2,
-	kWvMode3
-} GxWaveviewMode;
-
-/* wave view global */
-extern bool           new_wave_view;
 
 /* global GUI widgets */
 extern GtkWidget* fWindow;
 extern GtkWidget* menuh;
 extern GtkWidget* midibox;
-extern GtkWidget* fbutton;
-extern GtkWidget* record_button;
-extern GtkWidget* jc_dialog;
 extern GtkWidget* patch_info;
+extern GtkWidget* tuner_widget;
+extern GtkWidget* rack_widget;
+extern GtkWidget* menu_mono_rack;
+extern GtkWidget* srack_widget;
+extern GtkWidget* menu_stereo_rack;
+extern GtkWidget* rack_tool_bar;
 
-/* wave view widgets */
+/* icon widgets */
 extern GdkPixbuf* ib;
 extern GdkPixbuf* ibm;
 extern GdkPixbuf* ibr;
@@ -229,8 +222,7 @@ extern GtkWidget* gx_engine_bypass_image;
 extern GtkWidget* gx_engine_item;
 
 /* some more widgets */
-extern GtkWidget* label6;
-extern GtkWidget* label1;
+
 extern GtkStatusIcon* status_icon;
 
 /* tuner and osilloscope*/
@@ -245,6 +237,19 @@ extern int last_skin;
 extern int no_opt_skin;
 extern int set_knob;
 
+/* rack handlig */
+extern int mono_plugs;
+extern int stereo_plugs;
+extern int refresh_size;
+
+/* widget orientation */
+extern float main_xorg;
+extern float main_yorg;
+
+/* Effect moduls box*/
+
+
+
 /* for level display */
 extern int meter_falloff;
 extern int meter_display_timeout;
@@ -253,9 +258,7 @@ extern int meter_display_timeout;
 extern volatile gint       program_change;
 extern sem_t               program_change_sem;
 
-extern int show_eq;
-
-extern int g_threads[5];
+extern int g_threads[10];
 
 }
 
