@@ -22,6 +22,7 @@
 #pragma once
 
 #include <gtkmm/checkmenuitem.h>
+#include <gtkmm/radiomenuitem.h>
 namespace gx_gui
 {
 
@@ -35,9 +36,24 @@ public:
 	//FIXME not gtk-2.12: MenuCheckItem() { set_use_underline(); }
 	MenuCheckItem(): Gtk::CheckMenuItem("", true) {}
 	void set_parameter(SwitchParameter *p);
+	void add_parameter(SwitchParameter *p);
+	SwitchParameter * get_parameter();
 };
 
-
+/* ---- linking menu items and parameter ---- */
+class RadioCheckItem: public Gtk::RadioMenuItem
+{
+private:
+	
+	SwitchParameter* param;
+	void on_my_toggled();
+public:
+	Gtk::RadioMenuItem::Group Group;
+	//FIXME not gtk-2.12: MenuCheckItem() { set_use_underline(); }
+	RadioCheckItem(): Gtk::RadioMenuItem(Group,"", true) {}
+	void set_parameter(SwitchParameter *p);
+	SwitchParameter * get_parameter();
+};
 /* --------------  function declarations ---------------- */
 GtkWidget *load_toplevel(GtkBuilder *builder, const char* filename, const char* windowname);
 gboolean gx_hide_eq( GtkWidget *widget, gpointer   data );
@@ -57,7 +73,6 @@ void gx_set_skin_change(float fskin);
 /* engine status and switch */
 void gx_refresh_engine_status_display();
 void gx_engine_switch (GtkWidget* widget, gpointer arg);
-void cab_conv_restart();
 
 /* jack client and port mapping functions */
 void gx_jack_is_down();
@@ -106,13 +121,22 @@ void gx_reset_units             (Glib::ustring group_id);
 void gx_reset_effects           (GtkWidget*, gpointer);
 void gx_show_about              (GtkWidget*, gpointer);
 
+void cab_conv_restart();
+void contrast_conv_restart();
+
 void gx_show_extended_settings    (GtkWidget*, gpointer);
 void gx_hide_extended_settings    (GtkWidget*, gpointer);
+void gx_show_menu_settings        (GtkWidget*, gpointer);
 void gx_user_disable_latency_warn (GtkWidget*, gpointer);
 gint gx_wait_latency_warn         ();
 int  gx_message_popup             (const char*);
 
 gboolean gx_delete_event       (GtkWidget*, gpointer);
+gboolean gx_set_default_size   (gpointer data);
+gboolean gx_set_default_ssize  (gpointer data);
+gboolean gx_set_sresizeable    (gpointer data);
+gboolean gx_set_default        (gpointer data);
+gboolean gx_set_resizeable     (gpointer data);
 
 /* -------------------------------------------------------------------------- */
 } /* end of gx_gui namespace */
