@@ -25,12 +25,16 @@
 #include <iostream>
 #include <gxwmm/bigknob.h>
 #include <gxwmm/smallknob.h>
+#include <gxwmm/smallknobr.h>
 #include <gxwmm/wheel.h>
 #include <gxwmm/hslider.h>
 #include <gxwmm/eqslider.h>
+#include <gxwmm/levelslider.h>
+#include <gxwmm/minislider.h>
 #include <gxwmm/switch.h>
 #include <gxwmm/selector.h>
 #include <gxwmm/valuedisplay.h>
+#include <gxwmm/simplevaluedisplay.h>
 #include <gxwmm/fastmeter.h>
 #include <gxwmm/tuner.h>
 #include <gxwmm/waveview.h>
@@ -107,6 +111,46 @@ public:
  ** ---------------- the main GUI class ----------------
  **
  */
+ 
+ class GuiVariables
+{
+public:
+
+	bool fdialogbox1;
+	bool fdialogbox2;
+	bool fdialogbox3;
+	bool fdialogbox4;
+	bool fdialogbox6;
+	bool fdialogbox8;
+	bool fdialogbox_eq;
+	bool fdialogbox_eqs;
+	bool fdialogbox_mbf;
+	bool fdialogbox_moo;
+	bool fdialogbox_pha;
+	bool fdialogbox_se;
+	bool fdialogbox_wv;
+	bool fdialogbox_echo;
+	bool fdialogbox_delay;
+	bool fdialogbox_ovd;
+	bool fdialogbox_lh;
+	bool fdialogbox_sd;
+	bool fchorusbox;
+	bool fflangerbox;
+	bool fampmodul;
+	bool ftonemodule;
+	bool ftremolo_dialog;
+	bool fbiquadbox;
+	bool fphaser_mono_dialog;
+	bool fchorus_mono_dialog;
+	bool fflanger_mono_dialog;
+	bool ffeedback_dialog;
+	bool ftonestack_dialog;
+	bool fcabinet_dialog;
+
+void register_gui_parameter();
+};
+
+extern GuiVariables guivar;
 
 void gx_start_stop_jconv(GtkWidget*, gpointer);
 
@@ -160,10 +204,37 @@ private:
 public:
 	static GtkWidget* create(gx_ui::GxUI& ui, Gxw::Regler *regler, string id, bool show_value);
 	static GtkWidget* create(gx_ui::GxUI& ui, Gxw::Regler *regler, string id, Glib::ustring label, bool show_value);
+	
 	UiReglerWithCaption(gx_ui::GxUI &ui, FloatParameter &param, Gxw::Regler *regler, Glib::ustring label, bool show_value);
 	GtkWidget *get_widget() { return GTK_WIDGET(m_box.gobj()); }
 };
 
+class UiRackReglerWithCaption: public UiRegler
+{
+private:
+	Gtk::Label m_label;
+	Gtk::VBox m_box;
+public:
+	static GtkWidget* create(gx_ui::GxUI& ui, Gxw::Regler *regler, string id);
+	static GtkWidget* create(gx_ui::GxUI& ui, Gxw::Regler *regler, string id, Glib::ustring label);
+	
+	UiRackReglerWithCaption(gx_ui::GxUI &ui, FloatParameter &param, Gxw::Regler *regler, Glib::ustring label);
+	GtkWidget *get_widget() { return GTK_WIDGET(m_box.gobj()); }
+};
+
+class UiRackRegler: public UiRegler
+{
+private:
+	Gtk::Label m_label;
+	Gtk::VBox m_box;
+public:
+	static GtkWidget* create(gx_ui::GxUI& ui, Gxw::Regler *regler, string id);
+	static GtkWidget* create(gx_ui::GxUI& ui, Gxw::Regler *regler, string id, Glib::ustring label);
+	
+	UiRackRegler(gx_ui::GxUI &ui, FloatParameter &param, Gxw::Regler *regler, Glib::ustring label);
+	GtkWidget *get_widget() { return GTK_WIDGET(m_box.gobj()); }
+};
+
 class UiSwitch: public Gxw::Switch
 {
 public:
@@ -224,6 +295,15 @@ public:
 	UiCabSwitch(gx_ui::GxUI &ui, Parameter &param, Glib::ustring label);
 };
 
+class UiContrastSwitch: public UiSwitchWithCaption
+{
+private:
+	void on_switch_toggled();
+public:
+	static GtkWidget* create(gx_ui::GxUI& ui, string id, Glib::ustring label);
+	UiContrastSwitch(gx_ui::GxUI &ui, Parameter &param, Glib::ustring label);
+};
+
 struct uiTuner : public gx_ui::GxUiItemFloat, public Gtk::Alignment
 {
 private:
@@ -248,7 +328,8 @@ private:
 	void addPresetMenu();
 	void addExtraPresetMenu();
 
-	//void addPluginMenu();
+	void addPluginMenu();
+	void addAmpMenu();
 
 	void addOptionMenu();
 	void addGuiSkinMenu();
@@ -257,12 +338,25 @@ private:
 
 	bool on_meter_button_release(GdkEventButton* ev);
 	void on_tuner_activate();
+	void gx_show_menu_settings(GtkWidget *widget, gpointer data);
+	void on_log_activate();
+	void on_rack_activate();
+	void on_rrack_activate();
+	void on_srack_activate();
+	void on_toolbar_activate();
+	void on_tube_activate();
+	void set_mouse_mode();
 	void on_show_oscilloscope();
 	bool on_refresh_oscilloscope();
 
 protected :
 	int			fTop;
 	GtkWidget*          fBox[stackSize];
+	GtkWidget*          rBox;
+	GtkWidget*          sBox;
+	GtkWidget*          tBox;
+	
+	
 	int 		fMode[stackSize];
 	bool		fStopped;
 	GtkTextView*        fLoggingWindow;
@@ -279,7 +373,9 @@ protected :
 	MenuCheckItem       fMidiInPreset;
 	MenuCheckItem       fShowTooltips;
 	MenuCheckItem       fShowTuner;
+	
 	MenuCheckItem       fShowWaveView;
+	MenuCheckItem       fSetMouse;
 #ifdef EXPERIMENTAL
 	MenuCheckItem       fShowExpWindow;
 #endif
@@ -292,6 +388,17 @@ protected :
 	virtual void pushBox(int mode, GtkWidget* w);
 
 public :
+	MenuCheckItem       fShowRack;
+	MenuCheckItem       fShowRRack;
+	MenuCheckItem       fShowSRack;
+	MenuCheckItem       fShowLogger;
+	MenuCheckItem       fShowMidiOut;
+	MenuCheckItem       fShowToolBar;
+	RadioCheckItem      fSelectTubeModel[12];
+
+	GtkWidget* 			logger;
+	GtkWidget*          RBox;
+	
 	static bool	 fInitialized;
 	int          highest_unseen_msg_level;
 
@@ -317,21 +424,27 @@ public :
 
 	GtkWidget*   const getJackLatencyItem(const jack_nframes_t bufsize) const;
 
-	GtkWidget*   const getMenu(const string name) const { return fMenuList.at(name); }
+	GtkWidget*   const getMenu(const string name) { return fMenuList[name]; }
 
 	// -- layout groups
+	void gx_build_mono_rack();
+	void gx_build_stereo_rack();
 	void openHorizontalOrderBox(const char* label,  float* posit);
 	void openHorizontalTableBox(const char* label);
 	void openHorizontalRestetBox(const char* label,  float* posit);
 	void openFrameBox(const char* label);
 	void openHorizontalBox(const char* label = "");
 	void openHorizontalhideBox(const char* label = "");
+	void openHorizontalhideBox1(const char* label = "");
 	void openVerticalBox(const char* label = "");
 	void openVerticalBox1(const char* label = "");
 	void openFlipLabelBox(const char* = "");
 	void openVerticalSwitchBox(const char* label, int state, int wit, float* zone);
 	void openVerticalMidiBox(const char* label = "");
 	void openDialogBox(const char *id_dialog, const char *id_switch);
+	void opensDialogBox(const char *id_dialog, const char *id_switch);
+	void openDialogBox(const char *id_dialog, const char *id_switch,const char *expose_funk);
+	void opensDialogBox(const char *id_dialog, const char *id_switch,const char *expose_funk);
 	void openPatchInfoBox(float* zone);
 	void openWarningBox(const char* label, float* zone);
 	void openEventBox(const char* label = "");
@@ -358,6 +471,7 @@ public :
 	void addToggleButton(const char* label, float* zone);
 	void addJToggleButton(const char* label, float* zone);
 	void addPToggleButton(const char* label, float* zone);
+	void addMToggleButton(const char* label, float* zone);
 	void addCheckButton(const char* label, float* zone);
 	void addNumEntry(const char* label, float* zone, float init, float min, float max, float step);
 	void addNumDisplay();
@@ -369,6 +483,7 @@ public :
 	void addCheckButton(string id, const char* label=0);
 	void addNumEntry(string id, const char* label=0);
 	void addPToggleButton(string id, const char* label=0);
+	void addMToggleButton(string id, const char* label=0);
 
 	// -- other
 	void show_msg(string msgbuf, gx_system::GxMsgType msgtype);
@@ -400,10 +515,59 @@ public :
 		{
 			addwidget(UiRegler::create(*this, new Gxw::SmallKnob(), id, true));
 		}
+	
+	void create_small_rackknob(string id)
+		{
+			addwidget(UiRackReglerWithCaption::create(*this, new Gxw::SmallKnob(), id));
+		}
+	void create_small_rackknob(string id, Glib::ustring label)
+		{
+			addwidget(UiRackReglerWithCaption::create(*this, new Gxw::SmallKnob(), id, label));
+		}
+	
+	void create_smallknob_no_value(string id)
+		{
+			addwidget(UiReglerWithCaption::create(*this, new Gxw::SmallKnob(), id, false));
+		}
+	void create_smallknob_no_value(string id, Glib::ustring label)
+		{
+			addwidget(UiReglerWithCaption::create(*this, new Gxw::SmallKnob(), id, label, false));
+		}
+	void create_smallknob_no_caption_no_value(string id)
+		{
+			addwidget(UiRegler::create(*this, new Gxw::SmallKnob(), id, false));
+		}
+		
+	void create_smallknobr(string id)
+		{
+			addwidget(UiReglerWithCaption::create(*this, new Gxw::SmallKnobR(), id, true));
+		}
+	void create_smallknobr(string id, Glib::ustring label)
+		{
+			addwidget(UiReglerWithCaption::create(*this, new Gxw::SmallKnobR(), id, label, true));
+		}
+		
+	void create_small_rackknobr(string id)
+		{
+			addwidget(UiRackReglerWithCaption::create(*this, new Gxw::SmallKnobR(), id));
+		}
+	void create_small_rackknobr(string id, Glib::ustring label)
+		{
+			addwidget(UiRackReglerWithCaption::create(*this, new Gxw::SmallKnobR(), id, label));
+		}
+		
+	void create_smallknobr_no_caption(string id)
+		{
+			addwidget(UiRegler::create(*this, new Gxw::SmallKnobR(), id, true));
+		}	
 	void create_wheel(string id, bool show_value = false)
 		{
 			addwidget(UiRegler::create(*this, new Gxw::Wheel(), id, show_value));
 		}
+	void create_wheel_with_value(string id, bool show_value = true)
+		{
+			addwidget(UiRegler::create(*this, new Gxw::Wheel(), id, show_value));
+		}
 	void create_hslider(string id)
 		{
 			addwidget(UiReglerWithCaption::create(*this, new Gxw::HSlider(), id, true));
@@ -412,6 +576,15 @@ public :
 		{
 			addwidget(UiReglerWithCaption::create(*this, new Gxw::HSlider(), id, label, true));
 		}
+	void create_minislider(string id)
+		{
+			addwidget(UiRegler::create(*this, new Gxw::MiniSlider(), id, false));
+		}
+	void create_minislider(string id, Glib::ustring(label))
+		{
+			addwidget(UiReglerWithCaption::create(*this, new Gxw::MiniSlider(), id, label, true));
+		}
+		
 	void create_eqslider_no_caption(string id, bool show_value = true)
 		{
 			addwidget(UiRegler::create(*this, new Gxw::EqSlider(), id, show_value));
@@ -428,10 +601,50 @@ public :
 		{
 			addwidget(UiReglerWithCaption::create(*this, new Gxw::EqSlider(), id, label, show_value));
 		}
+		// levelslider
+	void create_levelslider_no_caption(string id, bool show_value = true)
+		{
+			addwidget(UiRegler::create(*this, new Gxw::LevelSlider(), id, show_value));
+		}
+	void create_levelslider(string id, bool show_value = true)
+		{
+			addwidget(UiReglerWithCaption::create(*this, new Gxw::LevelSlider(), id, show_value));
+		}
+	void create_levelslider(string id, Glib::ustring label, bool show_value = true)
+		{
+			addwidget(UiReglerWithCaption::create(*this, new Gxw::LevelSlider(), id, label, show_value));
+		}
+	void create_levelslider(string id, const char *label, bool show_value = true)
+		{
+			addwidget(UiReglerWithCaption::create(*this, new Gxw::LevelSlider(), id, label, show_value));
+		}
+		//rack
+	void create_eq_rackslider_no_caption(string id)
+		{
+			addwidget(UiRackRegler::create(*this, new Gxw::EqSlider(), id));
+		}
+	void create_eq_rackslider(string id)
+		{
+			addwidget(UiRackReglerWithCaption::create(*this, new Gxw::EqSlider(), id));
+		}
+	void create_eq_rackslider(string id, Glib::ustring label)
+		{
+			addwidget(UiRackReglerWithCaption::create(*this, new Gxw::EqSlider(), id, label));
+		}
+	void create_eq_rackslider(string id, const char *label)
+		{
+			addwidget(UiRackReglerWithCaption::create(*this, new Gxw::EqSlider(), id, label));
+		}
+		
 	void create_spin_value(string id)
 		{
 			addwidget(UiRegler::create(*this, new Gxw::ValueDisplay(), id, true));
 		}
+	void create_simple_spin_value(string id)
+		{
+			addwidget(UiRegler::create(*this, new Gxw::SimpleValueDisplay(), id, true));
+		}
+		
 	void create_selector(string id)
 		{
 			addwidget(UiSelector::create(*this, id));
@@ -452,6 +665,10 @@ public :
 		{
 			addwidget(UiCabSwitch::create(*this, id, label));
 		}
+	void create_contrast_switch(string id, Glib::ustring label, Gtk::PositionType pos = Gtk::POS_TOP)
+		{
+			addwidget(UiContrastSwitch::create(*this, id, label));
+		}
 };
 
 struct uiAdjustment : public gx_ui::GxUiItemFloat
@@ -484,6 +701,9 @@ extern const char *sw_rbutton;
 
 gboolean button_press_cb (GtkWidget *widget, GdkEventButton *event, gpointer data);
 
+int gx_set_mx_oriantation();
+int gx_set_my_oriantation();
+
 #ifndef NDEBUG
 // debug_check
 inline void check_zone(GtkWidget *w, void *zone)
